Save/resume fail test coverage -- test works in Docker now
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index b80104d8a9bb044e06f61ee950d90bb52c11021a..3091413e36fde70bd0194f6b8b6e20fecf4d1c0a 100644 (file)
--- a/score.c
+++ b/score.c
@@ -50,14 +50,14 @@ long score(enum termination mode)
         }
     }
 
/*  Now look at how he finished and how far he got.  MAXDIE and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (MAXDIE - game.numdie) * 10;
-    mxscor += MAXDIE * 10;
+    score += (maximum_deaths - game.numdie) * 10;
+    mxscor += maximum_deaths * 10;
     if (mode == endgame)
         score += 4;
     mxscor += 4;
@@ -78,7 +78,7 @@ long score(enum termination mode)
     mxscor += 45;
 
     /* Did he come to Witt's End as he should? */
-    if (game.place[MAGZIN] == LOC_WITTSEND)
+    if (game.place[MAGAZINE] == LOC_WITTSEND)
         score += 1;
     mxscor += 1;
@@ -50,14 +50,14 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  MAXDIE and
+    /*  Now look at how he finished and how far he got.  maximum_deaths and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still